#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-7phHyY0qkA7AsfaglgXKAx
key:                  coinbase-pro-0.9.3.2-7phHyY0qkA7AsfaglgXKAx
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  23c5a53b81ad4a5582ae8f7ec10aa21e
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-7phHyY0qkA7AsfaglgXKAx
depends:
    HsOpenSSL-0.11.7.10-JHnEhJ6s6LoGJhGPT0Ka5O
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf
    aeson-casing-0.2.0.0-E9wAZ8qc0MjKbtNEM7Cv76
    async-2.2.6-JCsfEU6uxaM3jchWvvttZs base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-G55UVChynYyJLpDwDEOvTE exceptions-0.10.7
    http-api-data-0.6.1-JS3AyagWAbIFbbYJuAGbBd
    http-client-0.7.19-34xXemB7zi7LDrAIS2UIas
    http-client-tls-0.3.6.4-ADnxKMmkuxZIenWWL3GTLT
    http-streams-0.8.9.9-LMIKNwatphrGzygduawfAR
    http-types-0.12.4-EqZKGcmXGQgIrxcsE0a1PI
    io-streams-1.5.2.2-BBcc5FVQ7FkBzQ3BwZ1ChG
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-IFm2hwedGEHKSyVo9U41Hp
    servant-0.20.3.0-1ojPzTaVV46EMvhC5B2CFn
    servant-client-0.20.3.0-H9FipnljlkSFq9FfjEYbBb
    servant-client-core-0.20.3.0-L53ug0eCQvELJ87IuL1r0N
    tasty-1.5.3-3DWM44dsHr08qjtH5pdhro
    tasty-hunit-0.10.2-5MZd2mZRGK24zPjmz9Dxm4 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-F88lh8p4g2v9Re7JG8Lsqj
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    uuid-1.3.16.1-KneWwsna7qdEDg4XfmCp0x
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX
    websockets-0.12.7.3-9sMr5cicmevI5Q6BGTz9vq
    wuss-2.0.1.7-Izv8vtP0dbt4Y4L1391kgK

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

